M$ModelName = "LQ_R2";

(* 
   
FeynRules model file for R2 = (3,2,7/6) scalar leptoquark. It is based on the Physics Reports 641 (2016) 1-68. See Eq. (3) of Phys. Rep. for notation. R2 has two electric charge eigenstate components denoted R2p53 (Q=+5/3) and R2p23 (Q=+2/3) with common mass MR2. The relevant decay widths for R2p53 and R2p23 are WR253 and WR223, respectively.

*)


M$Information = {Authors -> {"I. Dorsner", "A. Greljo"}, 
                 Version -> "3.0",
                 Date    -> "02. 12. 2017"};


M$InteractionOrderHierarchy = {
  {QCD, 1},
  {QED, 2},
  {NP,2} 
};


M$Parameters = {
 
(* R2 leptoquark Yukawa couplings *)
  
   yRL == { 
    	ParameterType    -> External,
	ComplexParameter -> False,
    	Indices          -> {Index[Generation], Index[Generation]},
	BlockName        -> YUKR2RL,
    	Value            -> {yRL[1,1] -> 0.1, yRL[1,2] -> 0.1, yRL[1,3] -> 0.1,
                      	     yRL[2,1] -> 0.1, yRL[2,2] -> 0.1, yRL[2,3] -> 0.1,
                             yRL[3,1] -> 0.1, yRL[3,2] -> 0.1, yRL[3,3] -> 0.1},
    	TeX              -> Superscript[y,RL],
	InteractionOrder -> {NP, 1},
    	Description      -> "R2 leptoquark RL Yukawa coupling matrix"
},

   yLR == { 
    	ParameterType    -> External,
	ComplexParameter -> False,
    	Indices          -> {Index[Generation], Index[Generation]},
	BlockName        -> YUKR2LR,
    	Value            -> {yLR[1,1] -> 0.1, yLR[1,2] -> 0.1, yLR[1,3] -> 0.1,
                      	     yLR[2,1] -> 0.1, yLR[2,2] -> 0.1, yLR[2,3] -> 0.1,
                             yLR[3,1] -> 0.1, yLR[3,2] -> 0.1, yLR[3,3] -> 0.1},
    	TeX               -> Superscript[y,LR],
	InteractionOrder  -> {NP, 1},
    	Description       -> "R2 leptoquark LR Yukawa coupling matrix"
}

};

M$ClassesDescription = {

(*********************************)
(* Scalar doublet R2 = (3,2,7/6) *)
(*********************************)

(* physical fields *)

S[200] == {
ClassName        -> R2p53,
Mass             -> {MR2, 650},
Width            -> {WR253, 12.9},
SelfConjugate    -> False,
PropagatorLabel  -> "R253",
PropagatorType   -> D,
PropagatorArrow  -> None,
QuantumNumbers   -> {Q -> 5/3, LeptonNumber -> -1},
Indices          -> {Index[Colour]},
ParticleName     -> "R2p53",
AntiParticleName -> "R2p53*",
FullName         -> "R53"
},

S[201] == {
ClassName        -> R2p23,
Mass             -> {MR2, 650},
Width            -> {WR223, 12.9},
SelfConjugate    -> False,
PropagatorLabel  -> "R2p23",
PropagatorType   -> D,
PropagatorArrow  -> None,
QuantumNumbers   -> {Q -> 2/3, LeptonNumber -> -1},
Indices          -> {Index[Colour]},
ParticleName     -> "R2p23",
AntiParticleName -> "R2p23*",
FullName         -> "R23"
},

(* unphysical fields *)

S[203] == {
ClassName      -> R2,
Unphysical     -> True,
Indices        -> {Index[SU2D], Index[Colour]},
FlavorIndex    -> SU2D,
SelfConjugate  -> False,
QuantumNumbers -> {Y -> 7/6},
Definitions    -> { R2[1,cc_] :> R2p53[cc], R2[2,cc_] :> R2p23[cc] }
}

};


(********************* The Lagrangian *********************)


(***** Kinetic term *****)


LR2Kin := Module[ {mu,a,c},
ExpandIndices[DC[R2bar[a,c],mu] DC[R2[a,c],mu] - MR2^2 R2bar[a,c] R2[a,c], FlavorExpand->{SU2W,SU2D}]];

(***** LQ-quark-lepton interactions *****)

LR2YukRL :=  Module[ {a,b,sp,i,j,cc},
 ExpandIndices[- yRL[i,j] uRbar[sp,i,cc].LL[sp,b,j] R2[a,cc] Eps[a,b], FlavorExpand->{SU2D,Generation}]
];

LR2YukLR :=  Module[ {a,sp,i,j,cc},
  ExpandIndices[yLR[i,j] lRbar[sp,i].QL[sp,a,j,cc] R2bar[a,cc], FlavorExpand->{SU2D,Generation}]
];

(***** Complete R2 Lagrangian *****)


LR2 := LR2Kin + LR2YukRL + HC[LR2YukRL] + LR2YukLR + HC[LR2YukLR];


(***********************************************************)