M$ModelName = "LQ_R2~";

(* 
   
FeynRules model file for R2~ = (3,2,1/6) = R2t scalar leptoquark. It is based on the Physics Reports 641 (2016) 1-68. See Eq. (5) of Phys. Rep. for notation. R2~ has two electric charge eigenstate components denoted R2tp23 (Q=+2/3) and R2tm13 (Q=-1/3) with common mass MR2t. The relevant decay widths for R2tp23 and R2tm13 are WR2t23 and WR2t13, respectively.

*)


M$Information = {Authors -> {"I. Dorsner", "A. Greljo"}, 
                 Version -> "3.0",
                 Date    -> "02. 12. 2017"};


M$InteractionOrderHierarchy = {
  {QCD, 1},
  {QED, 2},
  {NP,2} 
};


M$Parameters = {
 
(* R2~ = R2t leptoquark Yukawa couplings *)
  
yRL == { 
    	ParameterType    -> External,
	ComplexParameter -> False,
    	Indices          -> {Index[Generation], Index[Generation]},
	BlockName        -> YUKR2t,
    	Value            -> {yRL[1,1] -> 0.1, yRL[1,2] -> 0.1, yRL[1,3] -> 0.1,
                      	     yRL[2,1] -> 0.1, yRL[2,2] -> 0.1, yRL[2,3] -> 0.1,
                             yRL[3,1] -> 0.1, yRL[3,2] -> 0.1, yRL[3,3] -> 0.1},
    	TeX              -> Superscript[y,RL],
	InteractionOrder -> {NP, 1},
    	Description      -> "R2~ leptoquark Yukawa coupling matrix"
       }

};

M$ClassesDescription = {

(****************************************)
(* Scalar doublet R2~ = (3,2,1/6) = R2t *)
(****************************************)

(* physical fields *)

S[200] == {
ClassName        -> R2tp23,
Mass             -> {MR2t, 650},
Width            -> {WR2t23, 12.931339},
SelfConjugate    -> False,
PropagatorLabel  -> "R2t23",
PropagatorType   -> D,
PropagatorArrow  -> None,
QuantumNumbers   -> {Q -> 2/3, LeptonNumber -> -1},
Indices          -> {Index[Colour]},
ParticleName     -> "R2tp23",
AntiParticleName -> "R2tp23*",
FullName         -> "R23"
},

S[201] == {
ClassName        -> R2tm13,
Mass             -> {MR2t, 650},
Width            -> {WR2t13, 12.931339},
SelfConjugate    -> False,
PropagatorLabel  -> "R2t13",
PropagatorType   -> D,
PropagatorArrow  -> None,
QuantumNumbers   -> {Q -> -1/3, LeptonNumber -> -1},
Indices          -> {Index[Colour]},
ParticleName     -> "R2tm13",
AntiParticleName -> "R2tm13*",
FullName         -> "R13"
},

(* unphysical fields *)

S[203] == {
ClassName      -> R2t,
Unphysical     -> True,
SelfConjugate  -> False,
QuantumNumbers -> {Y -> 1/6},
Indices        -> {Index[SU2D], Index[Colour]},
FlavorIndex    -> SU2D,
Definitions    -> {R2t[1,cc_] :> R2tp23[cc], R2t[2,cc_] :> R2tm13[cc]}
}

};


(********************* The Lagrangian *********************)


(***** Kinetic term *****)


LR2tKin := Module[ {mu,a,c},
ExpandIndices[DC[R2tbar[a,c],mu] DC[R2t[a,c],mu] - MR2t^2 R2tbar[a,c] R2t[a,c], FlavorExpand->{SU2W,SU2D}]];

(***** LQ-quark-lepton interactions *****)

LR2tYuk :=  Module[ {a,b,sp,i,j,cc},
 ExpandIndices[- yRL[i,j] dRbar[sp,i,cc].LL[sp,b,j] R2t[a,cc] Eps[a,b], FlavorExpand->{SU2D,Generation}]];

(***** Complete R2~ = R2t Lagrangian *****)


LR2t := LR2tKin + LR2tYuk + HC[LR2tYuk];


(***********************************************************)