M$ModelName = "LO_LQ_S1";

(* 
   
FeynRules model file for S1 = (3,1,-1/3) = S1m13 scalar leptoquark. It is based on the Physics Reports 641 (2016) 1-68. See Eq. (8) of Phys. Rep. for notation. The mass (decay width) of S1 is denoted MS1 (WS1). This model file is suitable for the leading order simulations only.

*)

M$Information = {Authors -> {"I. Dorsner", "A. Greljo"}, 
                 Version -> "5.0",
                 Date    -> "09.02.2018",
                 Emails  -> {"dorsner@fesb.hr"},
                 URLs    -> "http://lqnlo.hepforge.org"};

M$InteractionOrderHierarchy = {
  {QCD, 1},
  {QED, 2},
  {NP,1} 
};

M$Parameters = {

(* S1 = S1m13 leptoquark mass *)

MS1 =={ 
    ParameterType -> External,
    BlockName     -> LQPARAM,
    Value         -> 650.0,
    Description   -> "S1 mass"
},
 
(* S1 = S1m13 leptoquark Yukawa couplings *)

yLL == { 
    	ParameterType    -> External,
	ComplexParameter -> False,
    	Indices          -> {Index[Generation], Index[Generation]},
	BlockName        -> YUKS1LL,
    	Value            -> {yLL[1,1] -> 0.1, yLL[1,2] -> 0.0, yLL[1,3] -> 0.0,
                      	     yLL[2,1] -> 0.0, yLL[2,2] -> 0.0, yLL[2,3] -> 0.0,
                             yLL[3,1] -> 0.0, yLL[3,2] -> 0.0, yLL[3,3] -> 0.0},
    	TeX              -> Superscript[y,LL],
	InteractionOrder -> {NP, 1},
    	Description      -> "S1 leptoquark LL Yukawa coupling matrix"
},

yRR == { 
    	ParameterType    -> External,
	ComplexParameter -> False,
    	Indices          -> {Index[Generation], Index[Generation]},
	BlockName        -> YUKS1RR,
    	Value            -> {yRR[1,1] -> 0.1, yRR[1,2] -> 0.0, yRR[1,3] -> 0.0,
                      	     yRR[2,1] -> 0.0, yRR[2,2] -> 0.0, yRR[2,3] -> 0.0,
                             yRR[3,1] -> 0.0, yRR[3,2] -> 0.0, yRR[3,3] -> 0.0},
    	TeX              -> Superscript[y,RR],
	InteractionOrder -> {NP, 1},
    	Description      -> "S1 leptoquark RR Yukawa coupling matrix"
},

(* S1 = S1m13 leptoquark decay width *)

WS1 == {
   ParameterType -> Internal,
   Value         -> (MS1*(Abs[yLL[1,1]]^2 + Abs[yLL[1,2]]^2 + Abs[yLL[1,3]]^2 
			+ Abs[yLL[2,1]]^2 + Abs[yLL[2,2]]^2 + Abs[yLL[2,3]]^2 
                        + Abs[yLL[3,1]]^2 + Abs[yLL[3,2]]^2 + Abs[yLL[3,3]]^2 
                        + Abs[yRR[1,1]]^2 + Abs[yRR[1,2]]^2 + Abs[yRR[1,3]]^2 
			+ Abs[yRR[2,1]]^2 + Abs[yRR[2,2]]^2 + Abs[yRR[2,3]]^2 
                        + Abs[CKM[1,1]*yLL[1,1]+CKM[1,2]*yLL[2,1]]^2 
                        + Abs[CKM[1,1]*yLL[1,2]+CKM[1,2]*yLL[2,2]]^2 
                        + Abs[CKM[1,1]*yLL[1,3]+CKM[1,2]*yLL[2,3]]^2 
                        + Abs[CKM[2,1]*yLL[1,1]+CKM[2,2]*yLL[2,1]]^2 
                        + Abs[CKM[2,1]*yLL[1,2]+CKM[2,2]*yLL[2,2]]^2 
                        + Abs[CKM[2,1]*yLL[1,3]+CKM[2,2]*yLL[2,3]]^2) 
                       + (Abs[yLL[3,1]]^2 + Abs[yLL[3,2]]^2 + Abs[yLL[3,3]]^2 
                        + Abs[yRR[3,1]]^2 + Abs[yRR[3,2]]^2 + Abs[yRR[3,3]]^2)*(MS1^2-ymt^2)^2/MS1^3)/(16*Pi)
}

};

M$ClassesDescription = {

(******************************************)
(* Scalar singlet S1 = (3,1,-1/3) = S1m13 *)
(******************************************)

(* physical fields *)

S[200] == {
ClassName        -> S1m13,
Mass             -> {MS1, Internal},
Width            -> {WS1, Internal},
SelfConjugate    -> False,
PropagatorLabel  -> "S1m13",
PropagatorType   -> D,
PropagatorArrow  -> None,
QuantumNumbers   -> {Q -> -1/3, LeptonNumber -> 1},
Indices          -> {Index[Colour]},
ParticleName     -> "S1m13",
AntiParticleName -> "S1m13*",
FullName         -> "S1m13"
}

};


(********************* The Lagrangian *********************)


(***** Kinetic term *****)


LS1Kin := Module[ {mu,c},
DC[S1m13bar[c],mu] DC[S1m13[c],mu] - MS1^2 S1m13bar[c] S1m13[c]
];

(***** LQ-quark-lepton interactions *****)

LS1Yuk1 :=  Module[ {a,b,sp,i,j,cc},
 ExpandIndices[yLL[i,j] anti[CC[QL]][sp,a,i,cc].LL[sp,b,j] S1m13bar[cc] Eps[a,b], FlavorExpand->{SU2D,Generation}]
];

LS1Yuk2 :=  Module[ {sp,i,j,cc},
 ExpandIndices[yRR[i,j] anti[CC[uR]][sp,i,cc].lR[sp,j] S1m13bar[cc], FlavorExpand-> Generation]
];


(***** Complete S1 Lagrangian *****)


LS1 := LS1Kin + LS1Yuk1 + HC[LS1Yuk1] + LS1Yuk2 + HC[LS1Yuk2];


(***********************************************************)