(* ********************************************************* *)
(* *****                                               ***** *)
(* *****  FeynRules model file: SM + Leptokvark @ NLO  ***** *)
(* *****  Author: A. Greljo                            ***** *)
(* *****                                               ***** *)
(* ********************************************************* *)

(* ************************** *)
(* *****  Information   ***** *)
(* ************************** *)
M$ModelName = "Leptokvark";
M$Information = {
  Authors      -> {"Admir Greljo"},
  Emails       -> {"admgrelj@uni-mainz.de"},
  Institutions -> {"JGU Mainz"},
  Date         -> "23.11.17",
  Version      -> "1.0",
  References   -> "A. Greljo, I. Dorsner"
};


(* ************************** *)
(* *****  Orders        ***** *)
(* ************************** *)
M$InteractionOrderHierarchy = { {QCD, 1},  {QED, 2},  {NP,1} };
M$InteractionOrderLimit     = { {QCD, 99}, {QED, 99}, {NP,1} };

(* ************************** *)
(* *****     Fields     ***** *)
(* ************************** *)
M$ClassesDescription = {
  S[5] == {
    ClassName        -> lq,
    SelfConjugate    -> False,
    Indices          -> {Index[Colour]},
    Mass             -> {mLQ,400},
    Width            -> {wLQ,10},
    ParticleName     -> "lq",
    AntiParticleName -> "lq~",
    PDG              -> 9000002,
    PropagatorLabel  -> "LQ",
    PropagatorType   -> ScalarDash,
    PropagatorArrow  -> Forward,
    QuantumNumbers   -> {Q -> 2/3, LeptonNumber -> -1}
  }
};

(* ************************** *)
(* *****   Parameters   ***** *)
(* ************************** *)
M$Parameters = {

   guL == {
    TeX              -> Superscript[OverTilde[g],uL],
    ParameterType    -> External,
    ComplexParameter -> False,
    BlockName        -> NPqlLQ,
    Value            -> 1.0,
    InteractionOrder -> {NP,1},
    Description      -> "Left-handed LQ-u-ve coupling"},

   gcL == {
    TeX              -> Superscript[OverTilde[g],cL],
    ParameterType    -> External,
    ComplexParameter -> False,
    BlockName        -> NPqlLQ,
    Value            -> 1.0,
    InteractionOrder -> {NP,1},
    Description      -> "Left-handed LQ-c-vm coupling"},

   gdL == {
    TeX              -> Superscript[OverTilde[g],dL],
    ParameterType    -> External,
    ComplexParameter -> False,
    BlockName        -> NPqlLQ,
    Value            -> 1.0,
    InteractionOrder -> {NP,1},
    Description      -> "Left-handed LQ-d-e coupling"},

   gsL == {
    TeX              -> Superscript[OverTilde[g],sL],
    ParameterType    -> External,
    ComplexParameter -> False,
    BlockName        -> NPqlLQ,
    Value            -> 1.0,
    InteractionOrder -> {NP,1},
    Description      -> "Left-handed LQ-s-mu coupling"},

   gbL == {
    TeX              -> Superscript[OverTilde[g],bL],
    ParameterType    -> External,
    ComplexParameter -> False,
    BlockName        -> NPqlLQ,
    Value            -> 1.0,
    InteractionOrder -> {NP,1},
    Description      -> "Left-handed LQ-b-ta coupling"}

};

(* ************************** *)
(* *****   Lagrangian   ***** *)
(* ************************** *)
L1 := DC[lqbar[aa],mu] DC[lq[aa],mu] - mLQ^2 lqbar[aa] lq[aa];

L4:= lq[cc] ubar[ss1,cc].ve[ss2] guL ProjM[ss1,ss2] + lq[cc] cbar[ss1,cc].vm[ss2] gcL ProjM[ss1,ss2] + lq[cc] dbar[ss1,cc].e[ss2] gdL ProjM[ss1,ss2] + lq[cc] sbar[ss1,cc].mu[ss2] gsL ProjM[ss1,ss2] + lq[cc] bbar[ss1,cc].ta[ss2] gbL ProjM[ss1,ss2];

LagNP := L1 + L4 + HC[L4];
