(* ********************************************************* *)
(* *****                                               ***** *)
(* *****  FeynRules model file: SM + U1 leptokvark     ***** *)
(* *****  Author: A. Greljo                            ***** *)
(* *****                                               ***** *)
(* ********************************************************* *)

(* ************************** *)
(* *****  Information   ***** *)
(* ************************** *)
M$ModelName = "VectorLQ";
M$Information = {
  Authors      -> {"Admir Greljo"},
  Emails       -> {"admgrelj@uni-mainz.de"},
  Institutions -> {"JGU Mainz"},
  Date         -> "10.12.17",
  Version      -> "1.0",
  References   -> "A. Greljo, I. Dorsner"
};


(* ************************** *)
(* *****  Orders        ***** *)
(* ************************** *)
M$InteractionOrderHierarchy = { {QCD, 1},  {QED, 2},  {NP,1} };
M$InteractionOrderLimit     = { {QCD, 99}, {QED, 99}, {NP,1} };

(* ************************** *)
(* *****     Fields     ***** *)
(* ************************** *)
M$ClassesDescription = {
  V[5] == {
    ClassName        -> vlq,
    SelfConjugate    -> False,
    Indices          -> {Index[Colour]},
    Mass             -> {mLQ,1000},
    Width            -> {wLQ,10},
    ParticleName     -> "vlq",
    AntiParticleName -> "vlq~",
    PDG              -> 9000002,
    PropagatorLabel  -> "LQ",
    PropagatorType   -> Sine,
    PropagatorArrow  -> Forward,
    QuantumNumbers   -> {Q -> 2/3, LeptonNumber -> -1}
  }
};

(* ************************** *)
(* *****   Parameters   ***** *)
(* ************************** *)
M$Parameters = {

   kappa == {
    ParameterType    -> External,
    ComplexParameter -> False,
    BlockName        -> NPcoup,
    OrderBlock       -> 1,
    Value            -> 1.0,
    Description      -> "Non-minimal QCD coupling: YM=1, MC=0"},

   gtL == {
    TeX              -> Superscript[OverTilde[g],tL],
    ParameterType    -> External,
    ComplexParameter -> False,
    BlockName        -> NPcoup,
    OrderBlock       -> 2,
    Value            -> 0.1,
    InteractionOrder -> {NP,1},
    Description      -> "Left-handed LQ-t-nu coupling"},

   gbL == {
    TeX              -> Superscript[OverTilde[g],bL],
    ParameterType    -> External,
    ComplexParameter -> False,
    BlockName        -> NPcoup,
    OrderBlock       -> 3,
    Value            -> 0.1,
    InteractionOrder -> {NP,1},
    Description      -> "Left-handed LQ-b-ta coupling"}

};

(* ************************** *)
(* *****   Lagrangian   ***** *)
(* ************************** *)

L1 := - 1/2 (DC[vlqbar[nu,i], mu] - DC[vlqbar[mu,i], nu]) (DC[vlq[nu,i], mu] - DC[vlq[mu,i], nu]) + mLQ^2 vlqbar[mu,i] vlq[mu,i] - I gs kappa vlqbar[mu,i] FS[G,mu,nu,a] T[a,i,j] vlq[nu,j];

L4:= gbL vlq[mu,i] bbar[ss0,i].ta[ss2] Ga[mu,ss0,ss1] ProjM[ss1,ss2] + gtL vlq[mu,i] tbar[ss0,i].vt[ss2] Ga[mu,ss0,ss1] ProjM[ss1,ss2];

LagNP := L1 + L4 + HC[L4];
